#!/usr/bin/python
#
# Copyright (c) 2019  Peter Pentchev <roam@ringlet.net>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

""" Get the change log out of the README file. """

from __future__ import print_function


import re
import sys


RE_VERSION = re.compile(r'''
    ^
    \#\# \s+ Version \s history
    \n+
    (?P<contents>
        .*?
    )
    \n+
    (?:
         ^
        \#\# \s+
        .*
            |
        \Z
    )
''', re.M | re.S | re.X)


def main():
    # type: () -> None
    """ Main program: parse the README file, output the change log. """
    with open('README.md', mode='r') as inf:
        contents = inf.read()

    data = RE_VERSION.search(contents)
    if not data:
        sys.exit('Could not parse README.md')

    with open('NEWS.md', mode='w') as outf:
        print('# Change log for trivrepr\n', file=outf)
        print(data.group('contents'), file=outf)


if __name__ == '__main__':
    main()
